@@ -113,7 +113,12 @@ int setup_tcp() {
         return r;
     }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4,11,0)
+    r = accept->ops->accept(control,accept,0,true);
+#else
     r = accept->ops->accept(control,accept,0);
+#endif
+
     if (r < 0) {
         DBG("Error accepting socket");
         return r;
